%function ReentryCorr(alpha)
%Criteria:
%Final velocity = Mach 2 or final altitude lie between 0 and 20 km

clc
clear all
format long e

%CONTROL VARIABLES
alpha = 35;         %angle of attack

%PARAMETERS
S_ref = 12.97;      %reference area of capsule (m^2)
R_E = 6.371*10^6;   %Earth's radius (m)
g_surf = 9.815;     %gravity at surface of the Earth (m/s^2)
m_vcl = 3855.54;    %mass of the capsule (kg)
alt_ref = 150*10^3; %end of sensible atmosphere (m)

param = [alt_ref, m_vcl, R_E, S_ref, g_surf];

theta = 0;         %flight path angle
k = 1;

%while theta <= 180
    
%STATE VARIABLE
V = 750;            %m/s
alt = 120000;       %m
phi = 0;           %angular displacement (range)

Pilot_penalty = 0;
Alt_penalty = 0;

t_0 = 0;            %initialize time
t = t_0;
dt = 0.1;           %time step

error = 1;          %initiate while loop
n = 1;

x = [phi, V, theta, alt, Pilot_penalty, Alt_penalty];

    while error > 0.01
        %INTEGRATE EQUATIONS OF MOTION
        %INTPUTS:   system state x at time t
        %           alpha
        %           parameters
        %OUTPUTS:   updated system state
        %           pilot penalty

        t = t + dt;
        time(n,1) = t;                  %store time values for plotting
        theta_ang(n,1) = theta;         %store theta values for plotting
        [x] = integrate_Motion_EQS(x, alpha, param, dt);
        Pilot_penalty = double(x(5));
        Alt_penalty = double(x(6));
        error = 1 - Pilot_penalty;
        %x = [phi, V, theta, alt, Pilot_penalty, Alt_penalty];
        
        %data(n,:) = [error, Pilot_penalty, Alt_penalty, alt, V, phi*180/pi, theta*180/pi];
        data(n,:,k) = [error, x(5), x(6), x(4), x(2), x(1), x(3)];
%         if x(2) <= 2*343% || x(4) > 0 && x(4) <= 20000
%             break
%         end
        n = n + 1;
    end
%     [PilotPen_max, ind] = min(data(:,1, k)); 
%     theta_max(k,:) = [data(ind,7, k)];
%     theta = theta + 1;
%     k = k + 1;
%end
disp(['Re-entry time = ', num2str(t), ' sec']);
% [C m] = max(theta_max);
% Maxdata = data(:,:,m);    

% f = figure('Position',[200 200 700 500]);
% cnames = {'error','Pilot Penalty','Altitude Penalty','Altitude','Velocity','Range', 'Flight-path Angle'};
% t = uitable('Parent',f,'Data',Maxdata,'ColumnName',cnames,'Position',[20 20 650 450]);
    
figure(1)
plot(time,data(:,4,1)/1000)
xlabel('Time (sec)')
ylabel('Altitude (km)')

figure(2)
plot(data(:,6,1),data(:,4,1)/1000)
xlabel('Range (degrees)')
ylabel('Altitude (km)')

figure(3)
plot(data(:,5,1),data(:,4,1)/1000)
xlabel('Velocity (m/s)')
ylabel('Altitude (km)')
