function [x] = integrate_Motion_EQS(x, alpha, param, dt)

%param = [alt_ref, m_vcl, R_E, S_ref, g_surf);
alt_ref = param(1);
m_vcl = param(2);
R_E = param(3);
S_ref = param(4);
g_surf = param(5);

%x = [phi, V, theta, alt, Pilot_penalty, Alt_penalty];
phi = x(1);
V = x(2);
theta = x(3);
alt = x(4);
Pilot_penalty = x(5);
Alt_penalty = x(6);

g = g_surf*(R_E/(R_E + alt))^2;

rho = 1.752*exp(-alt/6700);
%rho = 1.21 * exp(-(alt_ref-alt)/7000);

Cd =  2*(sind(alpha))^3;                        %Newtonian Theory
Cl =  2*(sind(alpha))^2*cosd(alpha);            %Newtonian Theory

D =  1/2*Cd*rho*V^2*S_ref;                      %calculate vehicle drag
L =  1/2*Cl*rho*V^2*S_ref;                      %calculate vehicle lift
Aero_accel = sqrt(L^2 + D^2)/(m_vcl*g_surf);    %calculte aerodynamic acceleration

tau =  0.0041*Aero_accel^4 - 0.2878*Aero_accel^3 + 7.7241*Aero_accel^2 - 93.667*Aero_accel + 437.21;     %from digitized data
u =  0*((alt - alt_ref) < 0) + 1*((alt - alt_ref) >= 0);      %step function

%SYSTEM EQUATIONS

V_dot = -D/m_vcl - g*sind(theta);
phi_dot = V*cosd(theta)/(R_E + alt);
theta_dot = (L/m_vcl - g*cosd(theta))/V - phi_dot;
alt_dot = -V*cosd(theta);
Pilot_penalty_dot = 1/tau;
Alt_penalty_dot = ((alt - alt_ref)/alt_ref)^2*u;

V = V + V_dot*dt;
phi = phi + phi_dot*dt;
theta = theta + theta_dot*dt;
alt = alt + alt_dot*dt;
Pilot_penalty = Pilot_penalty + Pilot_penalty_dot*dt;
Alt_penalty = Alt_penalty + Alt_penalty_dot*dt;

%UPDATE SYSTEM STATE VECTOR
x = [phi, V, theta, alt, Pilot_penalty, Alt_penalty]; 






